#!/usr/bin/env python
# -*- coding: utf-8 -*-

import logging
import unittest
import requests
from data_fixture.config_data import HOST_BOSS
from data_fixture import create_testdata as CreateTestData
from data_fixture import config_data as Data


#检查是否需要绑定保卡
class CheckElecCardBind(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + "/electronicCard/check"
        CreateTestData.pre_elecCard(Data.DEVICE_NUMBER_CUS_BIND, Data.DEVICE_NUMBER_SAM, Data.DEVICE_NUMBER_CUS_UNBIND)

    def tearDown(self):
        print(self.result)

    # 已绑定 -- 客机
    def test_checkElecCard_customerMachine(self):
        headers = {'Accept': '*/*'}
        getData = {'deviceNumber':Data.DEVICE_NUMBER_CUS_BIND}
        r = requests.get(self.base_url, headers=headers, params=getData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 1, 'checkElecCard_customerMachine Error')

    # 样机
    def test_checkElecCard_sampleMachine(self):
        headers = {'Accept': '*/*'}
        getData = {'deviceNumber': Data.DEVICE_NUMBER_SAM}
        r = requests.get(self.base_url, headers=headers, params=getData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 2002, 'checkElecCard_sampleMachine Error')

     # 未绑定 -- 客机
    def test_checkElecCard_unbind(self):
        headers = {'Accept': '*/*'}
        getData = {'deviceNumber': Data.DEVICE_NUMBER_CUS_UNBIND}
        r = requests.get(self.base_url, headers=headers, params=getData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 2001, 'checkElecCard_unbind Error')


#获取保卡信息
class GetCardInfo(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + "/electronicCard/info"
        CreateTestData.pre_elecCard(Data.DEVICE_NUMBER_CUS_BIND)

    def tearDown(self):
        print(self.result)

    def test_getCardInfo_success(self):
        headers = {'Accept': '*/*'}
        getData = {'deviceNumber': Data.DEVICE_NUMBER_CUS_BIND}
        r = requests.get(self.base_url, headers=headers, params=getData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 1, 'getCardInfo Error')
