#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
import requests
from data_fixture.config_data import HOST_BOSS, HOST_ADMIN
from data_fixture import create_testdata as CreateTestData
from data_fixture import config_data as Data


#添加客机保卡
class SetUpElecCard(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + "/electronicCard/addCustomer"
        CreateTestData.pre_SetUpElecCard()
    def tearDown(self):
        print(self.result)

    def test_addElecCard_success(self):
        headers = {'Content-Type': 'application/x-www-form-urlencoded', 'Accept': '*/*'}
        postData = {'userId':Data.USER_ID,
                    'customerName':'customer测试',
                    'customerAddress':'田林路487号',
                    'buyAddress':'虹梅路888号',
                    'buyTime':'2017-12-02',
                    'alterSaleCall':'55558888',
                    'productModel':'TEST',
                    'deviceNumber': Data.DEVICE_NUMBER_NEW,
                    'macAddress':Data.MAC_NEW,
                    'customerPhone':Data.USER_PHONE
        }
        r = requests.post(self.base_url, headers=headers, data=postData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 1, 'addElecCard Error')


# 置为样机，提交终端信息
class SetToSample(unittest.TestCase):

    def setUp(self):
        self.base_url = HOST_ADMIN + "/admin/elecCard/updateToSample"
        CreateTestData.pre_elecCard(device_cus_bind=Data.DEVICE_NUMBER_TO_SAM)

    def tearDown(self):
        pass

    def test_updateToSample_success(self):
        headers = {'Content-Type': 'multipart/form-data', 'Accept': 'application/json'}
        postData = {'userId':Data.USER_ID,
                    'deviceNumber':Data.DEVICE_NUMBER_TO_SAM,
                    'terminalAddress':'terminalAddress终端地址',
                    'distributor':'distributor经销商',
                    'saleClerk':'saleClerk销售员',
                    'mobilePhone':'18944444444'
                    }
        files = {'photo':('252ED989-0B16-4AB7-81C1-974ABCF6CA11.png','image/png')}
        r = requests.post(self.base_url, headers=headers, files=files, data=postData, allow_redirects=False)
        self.assertEqual(r.status_code, 302, 'updateToSampleError')


#置为客机
class SetToCustomer(unittest.TestCase):

    def setUp(self):
        self.base_url = HOST_ADMIN + "/admin/elecCard/updateToCustomer"
        CreateTestData.pre_elecCard(device_sam=Data.DEVICE_NUMBER_TO_CUS)

    def tearDown(self):
        pass

    def test_updateToCustomer_success(self):
        headers = {'Accept': 'application/json'}
        getData = {'userId': Data.USER_ID, 'deviceNumber': Data.DEVICE_NUMBER_TO_CUS}
        r = requests.get(self.base_url, data=getData, allow_redirects=False)
        self.assertEqual(r.status_code, 302, 'updateToCustomerError')


#解绑保卡
class Unbind(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_ADMIN + "/admin/elecCard/delete"
        CreateTestData.pre_elecCard(device_cus_bind=Data.DEVICE_NUMBER_UNBIND)

    def tearDown(self):
        pass

    def test_unbindCard_success(self):
        headers = {'Accept': '*/*'}
        getData = {'deviceNumber': Data.DEVICE_NUMBER_UNBIND}
        r = requests.get(self.base_url, headers=headers, data=getData, allow_redirects=False)
        # self.result = r.json()
        self.assertEqual(r.status_code, 302, 'unbindCardError')


#修改保卡
class Card_Modify(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + "/electronicCard/updateByUserId"
        CreateTestData.pre_elecCard(device_cus_bind=Data.DEVICE_NUMBER_EDIT)
        self.authCode = CreateTestData.fet_authCode(Data.USER_PHONE_EDIT)

    def tearDown(self):
        print(self.result)

    def test_modifyCardInfo_phone_success(self):
        headers = {'Content-Type': 'application/x-www-form-urlencoded', 'Accept': '*/*'}
        postData = {
            'customerPhone':Data.USER_PHONE_EDIT,
            'authCode':self.authCode,
            'deviceNumber': Data.DEVICE_NUMBER_EDIT
        }
        r = requests.post(self.base_url, headers=headers, data=postData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 1, 'elecCardModifyError')

    def test_modifyCardInfo_address_success(self):
        headers = {'Content-Type': 'application/x-www-form-urlencoded', 'Accept': '*/*'}
        postData = {
            'deviceNumber': Data.DEVICE_NUMBER_EDIT,
            'customerAddress': '上海徐汇区田林路888号修改',
            'customerPhone': Data.USER_PHONE_EDIT,
            'authCode':self.authCode
        }
        r = requests.post(self.base_url, headers=headers, data=postData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 1, 'elecCardModifyError')


