#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
import requests
from data_fixture.config_data import HOST_BOSS, HOST_STA
from data_fixture import create_testdata as CreateTestData
from data_fixture import config_data as Data
from data_fixture.mysql_db import DB
import uuid
import time



# 家长控制登录
class ParentSpaceLogin(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + '/parentsSpacePass/login'
        self.password = CreateTestData.get_parentSpace_password(Data.DEVICE_NUMBER_CUS_BIND)

    def tearDown(self):
        print(self.result)

    def test_ParentSpaceLogin_success(self):
        headers = {'Content-Type': 'application/x-www-form-urlencoded', 'Accept': '*/*'}
        postData = {'password': self.password,
                    'deviceNumber': Data.DEVICE_NUMBER_CUS_BIND
        }
        r = requests.post(self.base_url, headers=headers, data=postData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 1, 'ParentSpaceLogin Error')

    def test_ParentSpaceLogin_WrongPassword(self):
        password_wrong = self.password + '11'
        headers = {'Content-Type': 'application/x-www-form-urlencoded', 'Accept': '*/*'}
        postData = {'password': password_wrong,
                    'deviceNumber': Data.DEVICE_NUMBER_CUS_BIND
        }
        r = requests.post(self.base_url, headers=headers, data=postData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 1005, 'test_ParentSpaceLogin_WrongPassword Error')


# 家长控制修改密码
class ParentSpaceChangePassword(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + '/parentsSpacePass/changePassword'
        self.oldPass = CreateTestData.get_parentSpace_password(Data.DEVICE_NUMBER_CUS_BIND)

    def tearDown(self):
        print(self.result)

    def test_ParentSpaceChangePassword_success(self):
        headers = {'Content-Type': 'application/x-www-form-urlencoded', 'Accept': '*/*'}
        postData = {'oldPass': self.oldPass,
                    'newPass': '222222',
                    'deviceNumber': Data.DEVICE_NUMBER_CUS_BIND
        }
        r = requests.post(self.base_url, headers=headers, data=postData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 1, 'ParentSpacehangePassword Error')
        where = {'password': '222222',
                    'deviceNumber': Data.DEVICE_NUMBER_CUS_BIND }
        self.assertEqual(CreateTestData.db_select('acornuser.parents_space_pass', where), 1, 'ParentSpacehangePassword data Error')


#家长控制忘记密码
class ParentSpaceNewPassword(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + '/parentsSpacePass/newpassword'
        CreateTestData.pre_elecCard(Data.DEVICE_NUMBER_CUS_BIND)
        sql = "SELECT customerPhone FROM  acornuser.ozing_customermachine where deviceNumber = '{}'".format(Data.DEVICE_NUMBER_CUS_BIND)
        self.mobile = CreateTestData.db_select_bysql(sql)[0]["customerPhone"].strip()
        self.auth = CreateTestData.fet_authCode(self.mobile)

    def tearDown(self):
        pass

    def test_ParentSpaceNewPassword_success(self):
        headers = {'Content-Type': 'application/x-www-form-urlencoded', 'Accept': '*/*'}
        postData = {'userName': self.mobile,
                    'authCode': self.auth,
                    'password': '111111',
                    'deviceNumber': Data.DEVICE_NUMBER_CUS_BIND
        }
        r = requests.post(self.base_url, headers=headers, data=postData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 1, 'test_ParentSpaceNewPassword_success Error')
        where = {'password': '111111',
                    'deviceNumber': Data.DEVICE_NUMBER_CUS_BIND }
        self.assertEqual(CreateTestData.db_select('acornuser.parents_space_pass', where), 1, 'ParentSpacehangePassword data Error')

    def test_ParentSpaceNewPassword_authCodeError(self):
        headers = {'Content-Type': 'application/x-www-form-urlencoded', 'Accept': '*/*'}
        postData = {'userName': self.mobile,
                    'authCode': str(int(self.auth) - 1),
                    'password': '111111',
                    'deviceNumber': Data.DEVICE_NUMBER_CUS_BIND
        }
        r = requests.post(self.base_url, headers=headers, data=postData)
        self.result_2 = r.json()
        self.assertEqual(self.result_2['status'], 1001, 'test_ParentSpaceNewPassword_success Error')



