#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
import requests
from data_fixture.config_data import HOST_BOSS

# 省
class GetProvince(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + "/ozing/provinces"

    def tearDown(self):
        print(self.result)

    def test_getProvince_success(self):
        headers = {'Accept': '*/*'}
        r = requests.get(self.base_url, headers=headers)
        self.result = r.json()
        self.assertEqual(self.result['status'], 100, 'get province fail')
        self.assertTrue(len(self.result['provinces']) > 0, 'province data wrong')

# 市
class GetCities(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + "/ozing/cities"
        self.regionId = '330000' #浙江
        self.city ='330100' # 杭州

    def tearDown(self):
        print(self.result)

    def test_getCities_success(self):
        headers = {'Accept': '*/*'}
        getData = {'regionId': self.regionId}
        r = requests.get(self.base_url, params=getData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 100, 'get cities fail')
        self.assertTrue(len(self.result['cities']) > 0, 'cities data wrong')

# 区
class GetCounties(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + "/ozing/counties"
        self.regionId = '330100' # 杭州
        self.county ='330106' # 西湖

    def tearDown(self):
        print(self.result)

    def test_getCounties_success(self):
        headers = {'Accept': '*/*'}
        getData = {'regionId': self.regionId}
        r = requests.get(self.base_url, params=getData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 100, 'get counties fail')
        self.assertTrue(len(self.result['counties']) > 0, 'counties data wrong')

# 年级
class GetGrades(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + "/grades"

    def tearDown(self):
        print(self.result)

    def test_getGrades_success(self):
        headers = {'Accept': 'application/json'}
        r = requests.get(self.base_url, headers=headers)
        self.result = r.json()
        self.assertTrue(len(self.result['data']) > 0, 'grades data wrong')


# 学校
class GetSchools(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + "/school/get"
        self.regionId = '330106' #西湖
        self.gradeId = '6' #五年级

    def tearDown(self):
        print(self.result)

    def test_getSchools_success(self):
        headers = {'Accept': 'application/json'}
        getData = {'regionId': self.regionId, 'gradeId': self.gradeId}
        r = requests.get(self.base_url, headers=headers, params=getData)
        self.result = r.json()
        self.assertTrue(len(self.result['data']) > 0, 'school data wrong')
