#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
import requests
from data_fixture.config_data import HOST_BOSS,  HOST_RES
from data_fixture import create_testdata as CreateTestData
from data_fixture import config_data as Data
from data_fixture.mysql_db import DB



#获取同步视频接口
class ClassNameVideo(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_RES + '/className/video'

    def tearDown(self):
        pass

    def test_ClassNameVideo_success(self):
        getData = {'textName': '秋天的怀念',
                   'press': '人民教育出版社',
                   'subject': '语文',
                   'gradeName': '7年级'}
        r = requests.get(self.base_url,  params=getData)
        self.result_1 = r.json()
        self.assertEqual(self.result_1['status'], 1, 'test_ClassNameVideo_success Error')

    def test_ClassNameVideo_noData(self):
        getData = {'textName': '秋天 的怀念',
                   'press': '人民教育出版社',
                   'subject': '语文',
                   'gradeName': '7年级'}
        r = requests.get(self.base_url,  params=getData)
        self.result_2 = r.json()
        self.assertEqual(self.result_2['status'], 1000, 'test_ClassNameVideo_noData Error')


#获取知识点视频
class PointVideo(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_RES + '/point/video'

    def tearDown(self):
        pass

    def test_PointVideo_success(self):
        getData = {'textName': '秋天的怀念',
                   'press': '人民教育出版社',
                   'subject': '语文',
                   'gradeName': '7年级',
                   'point':'说明文阅读5说明文的结构||议论文的定义和分类'}
        r = requests.get(self.base_url,  params=getData)
        self.result_1 = r.json()
        self.assertEqual(self.result_1['status'], 1, 'test_PointVideo_success Error')

    def test_PointVideo_noData(self):
        getData = {'textName': '秋天的怀念',
                   'press': '人民教育出版社',
                   'subject': '语文',
                   'gradeName': '7年级',
                   'point': '说明文阅读5说明文的结构'}
        r = requests.get(self.base_url,  params=getData)
        self.result_2 = r.json()
        self.assertEqual(self.result_2['status'], 1000, 'test_PointVideo_noData Error')


#课程中心PK练习抽题接口
class SubjectTest(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + '/subject/test/'

    def tearDown(self):
        pass

    def test_SubjectTest_success(self):
        getData = {'subjectName': '数学',
                   'questionPoint': '二元一次方程||二元一次方程组的解',
                   'gradeId': '10',
                   'textName': '二元一次方程组'}
        url = self.base_url + 'math'
        r = requests.get(url,  params=getData)
        self.result_1 = r.json()
        self.assertEqual(self.result_1['status'], 1, 'test_SubjectTest_success Error')


#巩固练习抽题接口
class ConsolidationExercise(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + '/consolidation/exercise'

    def tearDown(self):
        pass

    def test_ConsolidationExercise_success(self):
        getData = {'subjectName': '数学',
                   'gradeId': '10',
                   'secondPoint': '二元一次方程||二元一次方程组的解',
                   'textName': '二元一次方程组',
                   'difficultyLevel': '基础卷'}
        r = requests.get(self.base_url,  params=getData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 1, 'test_ConsolidationExercise_success Error')
        self.assertTrue(len(self.result['data']) > 1)


#课程中心PK练习提交接口
class PKSubmitCheck(unittest.TestCase):
    def setUp(self):
        self.base_url = HOST_BOSS + '/submit/'

    def tearDown(self):
        pass

    def test_PKSubmitCheck_success(self):
        getData = {'subjectName': '数学',
                   'gradeId': '10',
                   'secondPoint': '二元一次方程||二元一次方程组的解',
                   'textName': '二元一次方程组',
                   'difficultyLevel': '基础卷'}
        r = requests.get(self.base_url,  params=getData)
        self.result = r.json()
        self.assertEqual(self.result['status'], 1, 'test_ConsolidationExercise_success Error')
        self.assertTrue(len(self.result['data']) > 1)


